;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'docbook '("dbide-process"))
(custom-add-loads 'languages '("docbookide"))
(custom-add-loads 'docbook-process '("dbide-process"))

;;; custom-load.el ends here
